==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/es_PA.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Pendientes",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Creaste el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} borró el calendario {calendar}",
    "You deleted calendar {calendar}" : "Borraste el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Actualizaste el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartido el calendario {calendar} contigo",
    "You shared calendar {calendar} with {user}" : "Compartiste el calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha dejado de compartir el calendario {calendar} contigo",
    "You unshared calendar {calendar} from {user}" : "Has dejado de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir {el calendario calendar} con él mismo",
    "You shared calendar {calendar} with group {group}" : "Compartiste el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Dejaste de compartir el calendario {calendar} con el grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendrio {calendar} con el grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Creaste el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} borró el eventó {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Borraste el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Actualizaste el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó el pendiente {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Creaste el pendiente {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} borró el pendiente {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Borraste el pendiente {todo} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó el pendiente {todo} de la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Actualizaste el pendiente {todo} de la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolvió el pendiente {todo} de la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Resolviste el pendiente {todo} de la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió el pendiente {todo} de la lista{calendar}",
    "You reopened todo {todo} in list {calendar}" : "Reabriste el pendiente {todo} de la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> de un calendario fue modificado",
    "A calendar <strong>todo</strong> was modified" : "Un <strong>pendiente</strong> de un calendario fue modificado",
    "Contact birthdays" : "Cumpleaños del contacto",
    "%s via %s" : "%s vía %s",
    "Invitation canceled" : "Invitación cancelada",
    "Hello %s," : "Hola %s,",
    "The meeting »%s« with %s was canceled." : "La cita »%s« con %s fue cancelada.",
    "Invitation updated" : "Invitación actualizada",
    "The meeting »%s« with %s was updated." : "La reunión »%s« con %s ha sido actualizada.",
    "%s invited you to »%s«" : "%s te ha invitado a »%s«",
    "When:" : "Cuándo:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Link:" : "Enlace:",
    "Contacts" : "Contactos",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "CalDAV server" : "Servidor CalDAV",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up the email settings above." : "Por favor asegurarte de establecer correctamente las configuraciones de correo anteriores. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/es_PA.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Pendientes",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Creaste el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} borró el calendario {calendar}",
    "You deleted calendar {calendar}" : "Borraste el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Actualizaste el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Compartiste el calendario {calendar} como una liga pública",
    "You removed public link for calendar {calendar}" : "Eliminaste la liga pública para el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartido el calendario {calendar} contigo",
    "You shared calendar {calendar} with {user}" : "Compartiste el calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha dejado de compartir el calendario {calendar} contigo",
    "You unshared calendar {calendar} from {user}" : "Has dejado de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir {el calendario calendar} con él mismo",
    "You shared calendar {calendar} with group {group}" : "Compartiste el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Dejaste de compartir el calendario {calendar} con el grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendrio {calendar} con el grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Creaste el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} borró el eventó {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Borraste el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Actualizaste el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó el pendiente {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Creaste el pendiente {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} borró el pendiente {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Borraste el pendiente {todo} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó el pendiente {todo} de la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Actualizaste el pendiente {todo} de la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolvió el pendiente {todo} de la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Resolviste el pendiente {todo} de la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió el pendiente {todo} de la lista{calendar}",
    "You reopened todo {todo} in list {calendar}" : "Reabriste el pendiente {todo} de la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> de un calendario fue modificado",
    "A calendar <strong>todo</strong> was modified" : "Un <strong>pendiente</strong> de un calendario fue modificado",
    "Contact birthdays" : "Cumpleaños del contacto",
    "%s via %s" : "%s vía %s",
    "Invitation canceled" : "Invitación cancelada",
    "Hello %s," : "Hola %s,",
    "The meeting »%s« with %s was canceled." : "La cita »%s« con %s fue cancelada.",
    "Invitation updated" : "Invitación actualizada",
    "The meeting »%s« with %s was updated." : "La reunión »%s« con %s ha sido actualizada.",
    "%s invited you to »%s«" : "%s te ha invitado a »%s«",
    "When:" : "Cuándo:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Link:" : "Enlace:",
    "Contacts" : "Contactos",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up the email settings above." : "Por favor asegurarte de establecer correctamente las configuraciones de correo anteriores. ",
    "Automatically generate a birthday calendar" : "Generar automaticamente un calendario para cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños serán generados por un trabajo de segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por lo tanto no estarán disponbiles inmediatamente después de habilitarlos pero se mostrarán después de un tiempo.",
    "CalDAV server" : "Servidor CalDAV"
},
"nplurals=2; plural=(n != 1);");
